==> v2.0.8.zip: alist/README_cn.md <==
<div align="center">
  <h3><a href="https://alist.nn.ci">Alist</a></h3>
  <p><em>🗂️一个支持多存储的文件列表程序，使用 Gin 和 React 。</em></p>
  <a href="https://github.com/Xhofe/alist/releases"><img src="https://img.shields.io/github/release/Xhofe/alist?style=flat-square" alt="latest version"></a>
  <a href="https://github.com/Xhofe/alist/discussions"><img src="https://img.shields.io/github/discussions/Xhofe/alist?color=%23ED8936&style=flat-square" alt="discussions"></a>
  <a href="https://github.com/Xhofe/alist/actions?query=workflow%3ABuild"><img src="https://img.shields.io/github/workflow/status/Xhofe/alist/build?style=flat-square" alt="Build status"></a>
  <a href="https://github.com/Xhofe/alist/releases"><img src="https://img.shields.io/github/downloads/Xhofe/alist/total?style=flat-square&color=%239F7AEA" alt="Downloads"></a>
  <a href="https://github.com/Xhofe/alist/blob/v2/LICENSE"><img src="https://img.shields.io/github/license/Xhofe/alist?style=flat-square" alt="License"></a>
  <a href="https://pay.xhofe.top">
    <img src="https://img.shields.io/badge/%24-donate-ff69b4.svg?style=flat-square" alt="donate">
  </a>
</div>

---

[English](./README.md) | 中文

## 支持

- [x] 多种存储
  - [x] 本地存储
  - [x] [阿里云盘](https://www.aliyundrive.com/)
  - [x] OneDrive / Sharepoint（[国际版](https://www.office.com/), [世纪互联](https://portal.partner.microsoftonline.cn),de,us）
  - [x] [天翼云盘](https://cloud.189.cn)
  - [x] [GoogleDrive](https://drive.google.com/)
  - [x] [123云盘](https://www.123pan.com/)
  - [x] [蓝奏云](https://pc.woozooo.com/)
  - [x] [Alist](https://github.com/Xhofe/alist)
  - [x] FTP
  - [x] [PikPak](https://www.mypikpak.com/)
  - [x] [闪电盘](https://shandianpan.com/)
  - [x] [S3](https://aws.amazon.com/cn/s3/)
  - [x] WebDav
  - [x] Teambition（[中国](https://www.teambition.com/ )，[国际](https://us.teambition.com/ )）
  - [x] [分秒帧](https://www.mediatrack.cn/)
  - [x] [和彩云](https://yun.139.com/) (个人云, 家庭云)
- [x] 部署方便，开箱即用
- [x] 文件预览（PDF、markdown、代码、纯文本……）
- [x] 画廊模式下的图像预览
- [x] 视频和音频预览（mp4、mp3 等）
- [x] Office 文档预览（docx、pptx、xlsx、...）
- [x] `README.md` 预览渲染
- [x] 文件永久链接复制和直接文件下载
- [x] 黑暗模式
- [x] 国际化
- [x] 受保护的路由（密码保护和身份验证）
- [x] WebDav（具体见https://alist-doc.nn.ci/docs/webdav ）
- [x] [Docker 部署](https://hub.docker.com/r/xhofe/alist)
- [x] Cloudflare workers 中转
- [x] 文件/文件夹打包下载
- [x] 支持视频列表播放和字幕(ass,srt,vtt)
- [x] 网页上传(可以允许访客上传)，删除，新建文件夹，重命名，移动，复制

## 讨论

一般问题请到[讨论论坛](https://github.com/Xhofe/alist/discussions) ，**issue仅针对错误报告。**

## 演示

<https://alist.nn.ci>。

![演示](https://inews.gtimg.com/newsapp_ls/0/14256614096/0)

## 文档

<https://alist-doc.nn.ci/>

##  许可

`AList` 是在 AGPL-3.0 许可下许可的开源软件。

---

> [@Blog](https://www.nn.ci/) · [@GitHub](https://github.com/Xhofe)

==> v2.4.0.zip: alist/README_cn.md <==
<div align="center">
  <a href="https://alist.nn.ci"><img height="100px" alt="logo" src="https://cdn.jsdelivr.net/gh/alist-org/logo@main/logo.svg"/></a>
  <p><em>🗂️一个支持多存储的文件列表程序，使用 Gin 和 React 。</em></p>
  <a href="https://github.com/Xhofe/alist/releases"><img src="https://img.shields.io/github/release/Xhofe/alist?style=flat-square" alt="latest version"></a>
  <a href="https://github.com/Xhofe/alist/discussions"><img src="https://img.shields.io/github/discussions/Xhofe/alist?color=%23ED8936&style=flat-square" alt="discussions"></a>
  <a href="https://github.com/Xhofe/alist/actions?query=workflow%3ABuild"><img src="https://img.shields.io/github/workflow/status/Xhofe/alist/build?style=flat-square" alt="Build status"></a>
  <a href="https://github.com/Xhofe/alist/releases"><img src="https://img.shields.io/github/downloads/Xhofe/alist/total?style=flat-square&color=%239F7AEA" alt="Downloads"></a>
  <a href="https://github.com/Xhofe/alist/blob/v2/LICENSE"><img src="https://img.shields.io/github/license/Xhofe/alist?style=flat-square" alt="License"></a>
  <a href="https://pay.xhofe.top">
    <img src="https://img.shields.io/badge/%24-donate-ff69b4.svg?style=flat-square" alt="donate">
  </a>
</div>

---

[English](./README.md) | 中文 | [Contributors](./CONTRIBUTORS.md) | [Contributing](./CONTRIBUTING.md)

## 支持

- [x] 多种存储
  - [x] 本地存储
  - [x] [阿里云盘](https://www.aliyundrive.com/)
  - [x] OneDrive / Sharepoint（[国际版](https://www.office.com/), [世纪互联](https://portal.partner.microsoftonline.cn),de,us）
  - [x] [天翼云盘](https://cloud.189.cn) (个人云, 家庭云)
  - [x] [GoogleDrive](https://drive.google.com/)
  - [x] [123云盘](https://www.123pan.com/)
  - [x] [蓝奏云](https://pc.woozooo.com/)
  - [x] [Alist](https://github.com/Xhofe/alist)
  - [x] FTP
  - [x] [PikPak](https://www.mypikpak.com/)
  - [x] [闪电盘](https://shandianpan.com/)
  - [x] [S3](https://aws.amazon.com/cn/s3/)
  - [x] WebDav(支持无API的OneDrive/SharePoint)
  - [x] Teambition（[中国](https://www.teambition.com/ )，[国际](https://us.teambition.com/ )）
  - [x] [分秒帧](https://www.mediatrack.cn/)
  - [x] [和彩云](https://yun.139.com/) (个人云, 家庭云)
  - [x] [Yandex.Disk](https://disk.yandex.com/)
  - [x] [百度网盘](http://pan.baidu.com/)
  - [x] [夸克网盘](https://pan.quark.cn)
  - [x] [迅雷云盘](https://pan.xunlei.com/)
  - [x] SFTP
- [x] 部署方便，开箱即用
- [x] 文件预览（PDF、markdown、代码、纯文本……）
- [x] 画廊模式下的图像预览
- [x] 视频和音频预览（mp4、mp3 等）
- [x] Office 文档预览（docx、pptx、xlsx、...）
- [x] `README.md` 预览渲染
- [x] 文件永久链接复制和直接文件下载
- [x] 黑暗模式
- [x] 国际化
- [x] 受保护的路由（密码保护和身份验证）
- [x] WebDav（具体见https://alist-doc.nn.ci/docs/webdav ）
- [x] [Docker 部署](https://hub.docker.com/r/xhofe/alist)
- [x] Cloudflare workers 中转
- [x] 文件/文件夹打包下载
- [x] 支持视频列表播放和字幕(ass,srt,vtt)
- [x] 网页上传(可以允许访客上传)，删除，新建文件夹，重命名，移动，复制

## 讨论

一般问题请到[讨论论坛](https://github.com/Xhofe/alist/discussions) ，**issue仅针对错误报告和功能请求。**

## 演示

<https://alist.nn.ci>。

![演示](https://store.heytapimage.com/cdo-portal/feedback/202202/20/b271627971e29f0c7c9d59935b6ef381.png)

## 文档

<https://alist-doc.nn.ci/>

## 特别赞助
- [找资源 - 阿里云盘资源搜索引擎](https://zhaoziyuan.la/)
- [JetBrains: Essential tools for software developers and teams](https://www.jetbrains.com/)

##  许可

`AList` 是在 AGPL-3.0 许可下许可的开源软件。

## 免责声明
- 本程序为免费开源项目，旨在分享网盘文件，方便下载以及学习golang，使用时请遵守相关法律法规，请勿滥用；
- 本程序通过调用官方sdk/接口实现，无破坏官方接口行为；
- 本程序仅做302重定向/流量转发，不拦截、存储、篡改任何用户数据；
- 在使用本程序之前，你应了解并承担相应的风险，包括但不限于账号被ban，下载限速等，与本程序无关；
- 如有侵权，请通过[邮件](mailto:i@nn.ci)与我联系，会及时处理。

---

> [@Blog](https://nn.ci/) · [@GitHub](https://github.com/Xhofe) · [@TelegramGroup](https://t.me/alist_chat) · [@QQGroup](https://jq.qq.com/?_wv=1027&k=OVPJcv2b)
